@@ -1,7 +1,7 @@
 "densityCOPplot" <-
- function(cop=NULL, para=NULL, deluv=0.002, origins=TRUE,
+ function(cop=NULL, para=NULL, deluv=0.002,
           getmatrix=c("none", "cdenzz", "cden"), n=0,
-          ploton=TRUE,
+          ploton=TRUE, snv=TRUE, origins=TRUE,
           contour.col=1, contour.lwd=1.5, ...) {
    getmatrix <- match.arg(getmatrix)
 
@@ -21,21 +21,32 @@
    rownames(cdenzz) <- V;  colnames(cdenzz) <- U
 
    if(ploton) {
-      xlim <- ylim <- c(-1,1)*rep(max(abs(range(c(qU, qV))), 2))
-      plot(xlim,ylim, type="n", xlim=xlim, ylim=ylim,
-           xlab="STANDARD NORMAL VARIATE OF U", ylab="STANDARD NORMAL VARIATE OF V")
-      if(origins) {
-         lines(xlim,rep(0,2),  lty=2)
-         lines(rep(0,2), ylim, lty=2)
+      if(snv) {
+        xlim <- ylim <- c(-1, 1)*rep(max(abs(range(c(qU, qV))), 2))
+        xlab <- "STANDARD NORMAL VARIATE OF U"
+        ylab <- "STANDARD NORMAL VARIATE OF V"
+      } else {
+        xlim <- ylim <- c(0, 1)
+        xlab <- "U, NONEXCEEDANCE PROBABILITY"
+        ylab <- "V, NONEXCEEDANCE PROBABILITY"
+      }
+      plot(xlim, ylim, type="n", xlim=xlim, ylim=ylim, xlab=xlab, ylab=ylab)
+      if(snv & origins) {
+         abline(h=0, lty=2)
+         abline(v=0, lty=2)
       }
    }
    if(n > 0) {
-      UV <- simCOP(n=n, cop=cop, para=para, ploton=FALSE, points=TRUE, snv=TRUE,
-                   pch=16, col=rgb(0,0,1,.3), cex=0.5, ...)
+      UV <- simCOP(n=n, cop=cop, para=para, ploton=FALSE, points=TRUE, snv=snv,
+                   pch=16, col=rgb(0, 0, 1, 0.3), cex=0.5, ...)
    }
    # The transposition t() is CRITICAL!!!!!!!! Let the 2nd example in
    # densityCOPplot(), which is highly asymmetrical be the canonical demonstration.
-   contour(x=qU, y=qV, z=t(cdenzz), lwd=contour.lwd, cex=2, add=TRUE, col=contour.col, ...)
+   if(snv) {
+     contour(x=qU, y=qV, z=t(cdenzz), lwd=contour.lwd, cex=2, add=TRUE, col=contour.col, ...)
+   } else {
+     contour(x=U, y=V,   z=t(cdenzz), lwd=contour.lwd, cex=2, add=TRUE, col=contour.col, ...)
+   }
 
    if(getmatrix == "cdenzz") {
       return(cdenzz)
